@@ -1,6 +1,7 @@
 __all__ = ('RESTRICT_PLUGIN_ACCESS', 'PLUGINS_MODULE_NAME', 'LAYOUTS_MODULE_NAME', 'ACTIVE_LAYOUT', \
            'LAYOUT_CELL_UNITS', 'DEFAULT_WORKSPACE_NAME', 'DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME', \
-           'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'DISPLAY_LOGOUT_LINK', 'DEBUG')
+           'DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME', 'DISPLAY_AUTH_LINK', 'WAIT_BETWEEN_TEST_STEPS', \
+           'WAIT_AT_TEST_END', 'DEBUG')
 
 gettext = lambda s: s
 
@@ -27,6 +28,9 @@ DEFAULT_PLACEHOLDER_VIEW_TEMPLATE_NAME = 'dash/layouts/base_placeholder_view.htm
 DEFAULT_PLACEHOLDER_EDIT_TEMPLATE_NAME = 'dash/layouts/base_placeholder_edit.html'
 
 # If set to True, the logout link is shown in the menu.
-DISPLAY_LOGOUT_LINK = True
+DISPLAY_AUTH_LINK = True
+
+WAIT_BETWEEN_TEST_STEPS = 2
+WAIT_AT_TEST_END = 4
 
 DEBUG = False
